@@ -47,7 +47,7 @@ def Redondear(expr):#Redondeamos la expresión.
   return Aproximacion
 
 
-def D(elemento,color = "red"):#Por default se imprime en rojo, para indicar que es un derivado.
+def D(elemento,color = "black"):#Por default se imprime en rojo, para indicar que es un derivado.
   print("")
   Tipo = None
   if isinstance(elemento,sympy.core.relational.Equality):#Si el elemento ingresado es una ecuación, entonces la identificamos
@@ -136,9 +136,9 @@ def S(c_componente):#Guardar
   
   #Renderizado Gris
   if c_componente[1] == None or dentro == False:
-    D(c_componente,"gray")#Hacemos un print renderizado en color gris para indicar que el elemento ha sido definido/guardado
+    D(c_componente,"black")#Hacemos un print renderizado en color gris para indicar que el elemento ha sido definido/guardado
   else:
-    D(c_componente,"red")#Hacemos un print renderizado en color gris para indicar que el elemento ha sido definido/guardado
+    D(c_componente,"black")#Hacemos un print renderizado en color gris para indicar que el elemento ha sido definido/guardado
 
 #def A(c_componente):#Actualizar
 #  color = "red"
@@ -159,7 +159,7 @@ def R(string):
 
 from artemix.latemix import *
 
-def E(expr,color ="red"):
+def E(expr,color ="black"):
   if isinstance(expr,sympy.core.relational.Equality):#Si tenemos una igualdad
     izquierda = expr.args[0]
     derecha = expr.args[1]
